@@ -1,9 +1,9 @@
 package Net::DNS::DomainName;
 
 #
-# $Id: DomainName.pm 1527 2017-01-18 21:42:48Z willem $
+# $Id: DomainName.pm 1555 2017-03-22 09:47:16Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1527 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1555 $)[1];
 
 
 =head1 NAME
@@ -68,7 +68,7 @@ as defined in RFC2535(8.1).
 =cut
 
 my $lc = sub {				## work around 5.8.x case-folding bug
-	( my $s = shift ) =~ tr [\101-\132] [\141-\172];
+	( my $s = shift ) =~ tr [A-Z] [a-z];
 	return $s;
 };
 
@@ -108,11 +108,10 @@ sub decode {
 	my $index  = $offset;
 
 	while ( $index < $buflen ) {
-		my $header = unpack( "\@$index C", $$buffer );
-		unless ($header) {				# terminal empty label
-			return wantarray ? ( $self, ++$index ) : $self;
+		my $header = unpack( "\@$index C", $$buffer )
+				|| return wantarray ? ( $self, ++$index ) : $self;
 
-		} elsif ( $header < 0x40 ) {			# non-terminal label
+		if ( $header < 0x40 ) {				# non-terminal label
 			push @$label, substr( $$buffer, ++$index, $header );
 			$index += $header;
 
