@@ -1,10 +1,9 @@
 package Net::DNS::Nameserver;
 
 #
-# $Id: Nameserver.pm 1493 2016-08-22 08:28:50Z willem $
+# $Id: Nameserver.pm 1537 2017-02-15 09:09:58Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1493 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1537 $)[1];
 
 
 =head1 NAME
@@ -31,17 +30,25 @@ objects.  See L</EXAMPLE> for an example.
 
 =cut
 
+use constant USE_SOCKET_IP => defined eval 'use Socket 1.98; use IO::Socket::IP 0.32; 1;';
+
+use constant USE_SOCKET_INET => defined eval 'require IO::Socket::INET';
+
+use constant USE_SOCKET_INET6 => defined eval 'require IO::Socket::INET6';
+
+use constant IPv6 => USE_SOCKET_IP || USE_SOCKET_INET6;
+
 
 use strict;
+use warnings;
 use integer;
 use Carp qw(cluck);
 use Net::DNS;
 
 use IO::Socket;
-use IO::Socket::INET;
 use IO::Select;
 
-use constant FORCE_INET4 => 0;
+use constant FORCE_IPv4 => 0;
 
 use constant DEFAULT_ADDR => 0;
 use constant DEFAULT_PORT => 53;
@@ -52,18 +59,6 @@ use constant STATE_SENDING    => 3;
 
 use constant PACKETSZ => 512;
 
-use vars qw($has_inet6);
-
-BEGIN {
-	$has_inet6 = eval {
-		require IO::Socket::INET6;
-		IO::Socket::INET6->VERSION("2.01");
-		1;
-	} || 0;
-
-	$has_inet6 = 0 if FORCE_INET4;
-}
-
 
 #------------------------------------------------------------------------------
 # Constructor.
@@ -88,7 +83,7 @@ sub new {
 			? @{$self{LocalAddr}}
 			: ( $self{LocalAddr} || DEFAULT_ADDR );
 	my $resolver = new Net::DNS::Resolver( nameservers => [@LocalAddr] );
-	$resolver->force_v4(1) unless $has_inet6;
+	$resolver->force_v4(1) if FORCE_IPv4;
 	my @localaddresses = $resolver->nameservers;
 
 	my $port = $self{LocalPort} || DEFAULT_PORT;
@@ -168,11 +163,14 @@ sub new {
 #------------------------------------------------------------------------------
 
 sub inet_new {
-	if ($has_inet6) {
-		return new IO::Socket::INET6(@_);
-	} else {
-		return new IO::Socket::INET(@_);
-	}
+	return new IO::Socket::INET(@_) unless IPv6;
+
+	return new IO::Socket::IP(@_) if USE_SOCKET_IP;
+
+	my %param = @_;
+
+	return new IO::Socket::INET6(@_) if $param{LocalAddr} =~ /:/;
+	return new IO::Socket::INET(@_);
 }
 
 #------------------------------------------------------------------------------
@@ -198,6 +196,7 @@ sub make_reply {
 	my $reply  = $query->reply();
 	my $header = $reply->header;
 	my $headermask;
+	my $optionmask;
 
 	my $opcode  = $query->header->opcode;
 	my $qdcount = $query->header->qdcount;
@@ -222,17 +221,25 @@ sub make_reply {
 		my @arglist = ( $qname, $qclass, $qtype, $peerhost, $query, $conn );
 
 		if ( $opcode eq "QUERY" ) {
-			( $rcode, $ans, $auth, $add, $headermask ) =
+			( $rcode, $ans, $auth, $add, $headermask, $optionmask ) =
 					&{$self->{ReplyHandler}}(@arglist);
 
 		} elsif ( $opcode eq "NOTIFY" ) {		#RFC1996
 			if ( ref $self->{NotifyHandler} eq "CODE" ) {
-				( $rcode, $ans, $auth, $add, $headermask ) =
+				( $rcode, $ans, $auth, $add, $headermask, $optionmask ) =
 						&{$self->{NotifyHandler}}(@arglist);
 			} else {
 				$rcode = "NOTIMP";
 			}
 
+		} elsif ( $opcode eq "UPDATE" ) {		#RFC2136
+			if ( ref $self->{UpdateHandler} eq "CODE" ) {
+				( $rcode, $ans, $auth, $add, $headermask, $optionmask ) =
+						&{$self->{UpdateHandler}}(@arglist);
+			} else {
+				$rcode = "NOTIMP";
+			}
+
 		} else {
 			print "ERROR: opcode $opcode unsupported\n" if $self->{Verbose};
 			$rcode = "FORMERR";
@@ -254,7 +261,11 @@ sub make_reply {
 		$header->$key($value);
 	}
 
-	$header->print if $self->{Verbose} && defined $headermask;
+	while ( my ( $option, $value ) = each %{$optionmask || {}} ) {
+		$reply->edns->option( $option, $value );
+	}
+
+	$header->print if $self->{Verbose} && ( $headermask || $optionmask );
 
 	return $reply;
 }
@@ -575,6 +586,9 @@ Attributes are:
     NotifyHandler	Reference to reply-handling
 			subroutine for queries with
 			opcode NOTIFY (RFC1996)
+    UpdateHandler	Reference to reply-handling
+			subroutine for queries with
+			opcode UPDATE (RFC2136)
     Verbose		Print info about received
 			queries.			Defaults to 0 (off).
     Truncate		Truncates UDP packets that
@@ -610,6 +624,9 @@ hashref with the settings for the C<aa>, C<ra>, and C<ad>
 header bits. The argument is of the form
 C<< { ad => 1, aa => 0, ra => 1 } >>.
 
+EDNS options may be specified in a similar manner using optionmask
+C<< { $optioncode => $value, $optionname => $value } >>.
+
 
 See RFC 1035 and the IANA dns-parameters file for more information:
 
@@ -709,16 +726,23 @@ additional filtering on its basis may be applied.
 		$rcode = "NXDOMAIN";
 	}
 
-	# mark the answer as authoritative (by setting the 'aa' flag
-	return ($rcode, \@ans, \@auth, \@add, { aa => 1 });
+	# mark the answer as authoritative (by setting the 'aa' flag)
+	my $headermask = { aa => 1 };
+
+	# specify EDNS options	{ option => value }
+	my $optionmask = { };
+
+	return ($rcode, \@ans, \@auth, \@add, $headermask, $optionmask });
     }
 
+
     my $ns = new Net::DNS::Nameserver(
 	LocalPort    => 5353,
 	ReplyHandler => \&reply_handler,
 	Verbose	     => 1
 	) || die "couldn't create nameserver object\n";
 
+
     $ns->main_loop;
 
 
