@@ -1,9 +1,9 @@
 package Net::DNS::Packet;
 
 #
-# $Id: Packet.pm 1527 2017-01-18 21:42:48Z willem $
+# $Id: Packet.pm 1546 2017-03-06 09:27:31Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1527 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1546 $)[1];
 
 
 =head1 NAME
@@ -191,7 +191,7 @@ sub encode {
 
 	my $edns = $self->edns;					# EDNS support
 	my @addl = grep !$_->isa('Net::DNS::RR::OPT'), @{$self->{additional}};
-	$self->{additional} = [@addl, $edns] if $edns->_specified;
+	$self->{additional} = [$edns, @addl] if $edns->_specified;
 
 	return $self->truncate($size) if $size;
 
