@@ -1,39 +1,26 @@
 package Net::DNS::Parameters;
 
 #
-# $Id: Parameters.pm 1521 2016-12-19 15:42:18Z willem $
+# $Id: Parameters.pm 1552 2017-03-13 09:44:07Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1521 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1552 $)[1];
 
 
 ################################################
 ##
 ##	Domain Name System (DNS) Parameters
-##	(last updated 2016-12-09)
+##	(last updated 2017-03-07)
 ##
 ################################################
 
 
 use strict;
+use warnings;
 use integer;
 use Carp;
 
-
-use vars qw($DNSEXTLANG);		## draft-levine-dnsextlang
-$DNSEXTLANG = 'ARPA.';
-
-use constant DNSEXTLANG => defined eval <<'END';
-	die 'preempt failure' if $^O =~ /cygwin|MSWin32/i;
-	require FileHandle;
-	local $SIG{__WARN__} = sub { };
-	new FileHandle('RRTYPEgen |');
-END
-
-
 use base qw(Exporter);
-use vars qw(@EXPORT);
-@EXPORT = qw(
+our @EXPORT = qw(
 		classbyname classbyval %classbyname
 		typebyname typebyval %typebyname
 		opcodebyname opcodebyval
@@ -43,21 +30,19 @@ use vars qw(@EXPORT);
 
 
 # Registry: DNS CLASSes
-use vars qw( %classbyname %classbyval );
-%classbyname = (
+our %classbyname = (
 	IN   => 1,						# RFC1035
 	CH   => 3,						# Chaosnet
 	HS   => 4,						# Hesiod
 	NONE => 254,						# RFC2136
 	ANY  => 255,						# RFC1035
 	);
-%classbyval = reverse %classbyname;
+our %classbyval = reverse %classbyname;
 %classbyname = ( '*' => 255, %classbyname, map lc($_), %classbyname );
 
 
 # Registry: Resource Record (RR) TYPEs
-use vars qw( %typebyname %typebyval );
-%typebyname = (
+our %typebyname = (
 	A	   => 1,					# RFC1035
 	NS	   => 2,					# RFC1035
 	MD	   => 3,					# RFC1035
@@ -143,26 +128,24 @@ use vars qw( %typebyname %typebyval );
 	TA	   => 32768,					# http://cameo.library.cmu.edu/ http://www.watson.org/~weiler/INI1999-19.pdf
 	DLV	   => 32769,					# RFC4431
 	);
-%typebyval = reverse %typebyname;
+our %typebyval = reverse %typebyname;
 %typebyname = ( '*' => 255, %typebyname, map lc($_), %typebyname );
 
 
 # Registry: DNS OpCodes
-use vars qw( %opcodebyname %opcodebyval );
-%opcodebyname = (
+our %opcodebyname = (
 	QUERY  => 0,						# RFC1035
 	IQUERY => 1,						# RFC3425
 	STATUS => 2,						# RFC1035
 	NOTIFY => 4,						# RFC1996
 	UPDATE => 5,						# RFC2136
 	);
-%opcodebyval = reverse %opcodebyname;
+our %opcodebyval = reverse %opcodebyname;
 %opcodebyname = ( NS_NOTIFY_OP => 4, %opcodebyname, map lc($_), %opcodebyname );
 
 
 # Registry: DNS RCODEs
-use vars qw( %rcodebyname %rcodebyval );
-%rcodebyname = (
+our %rcodebyname = (
 	NOERROR	  => 0,						# RFC1035
 	FORMERR	  => 1,						# RFC1035
 	SERVFAIL  => 2,						# RFC1035
@@ -185,13 +168,12 @@ use vars qw( %rcodebyname %rcodebyval );
 	BADTRUNC  => 22,					# RFC4635
 	BADCOOKIE => 23,					# RFC7873
 	);
-%rcodebyval = reverse( BADSIG => 16, %rcodebyname );
+our %rcodebyval = reverse( BADSIG => 16, %rcodebyname );
 %rcodebyname = ( %rcodebyname, map lc($_), %rcodebyname );
 
 
 # Registry: DNS EDNS0 Option Codes (OPT)
-use vars qw( %ednsoptionbyname %ednsoptionbyval );
-%ednsoptionbyname = (
+our %ednsoptionbyname = (
 	LLQ		=> 1,					# http://files.dns-sd.org/draft-sekar-dns-llq.txt
 	UL		=> 2,					# http://files.dns-sd.org/draft-sekar-dns-ul.txt
 	NSID		=> 3,					# RFC5001
@@ -204,29 +186,30 @@ use vars qw( %ednsoptionbyname %ednsoptionbyval );
 	'TCP-KEEPALIVE' => 11,					# RFC7828
 	PADDING		=> 12,					# RFC7830
 	CHAIN		=> 13,					# RFC7901
+	'KEY-TAG'	=> 14,					# RFC-ietf-dnsop-edns-key-tag-05
 	DEVICEID	=> 26946,				# https://docs.umbrella.com/developer/networkdevices-api/identifying-dns-traffic2
 	);
-%ednsoptionbyval = reverse %ednsoptionbyname;
+our %ednsoptionbyval = reverse %ednsoptionbyname;
 %ednsoptionbyname = ( %ednsoptionbyname, map lc($_), %ednsoptionbyname );
 
 
 # Registry: DNS Header Flags
-use vars qw( %dnsflagbyname );
-%dnsflagbyname = (
+our %dnsflagbyname = (
 	AA => 0x0400,						# RFC1035
 	TC => 0x0200,						# RFC1035
 	RD => 0x0100,						# RFC1035
 	RA => 0x0080,						# RFC1035
-	AD => 0x0020,						# RFC4035
-	CD => 0x0010,						# RFC4035
+	AD => 0x0020,						# RFC4035 RFC6840
+	CD => 0x0010,						# RFC4035 RFC6840
 	);
+%dnsflagbyname = ( %dnsflagbyname, map lc($_), %dnsflagbyname );
 
 
 # Registry: EDNS Header Flags (16 bits)
-use vars qw( %ednsflagbyname );
-%ednsflagbyname = (
+our %ednsflagbyname = (
 	DO => 0x8000,						# RFC4035 RFC3225
 	);
+%ednsflagbyname = ( %ednsflagbyname, map lc($_), %ednsflagbyname );
 
 
 ########
@@ -321,6 +304,16 @@ sub ednsoptionbyval {
 }
 
 
+our $DNSEXTLANG = 'ARPA.';		## draft-levine-dnsextlang
+
+use constant DNSEXTLANG => defined eval <<'END';
+	die 'preempt failure' if $^O =~ /cygwin|MSWin32/i;
+	require IO::File;
+	local $SIG{__WARN__} = sub { };
+	new IO::File('RRTYPEgen |') or die $!;
+END
+
+
 sub register {				## register( 'TOY', 1234 )	(NOT part of published API)
 	my ( $mnemonic, $rrtype ) = map uc($_), @_;		# uncoverable pod
 	$rrtype = rand(255) + 65280 unless $rrtype;
@@ -351,7 +344,7 @@ sub _typespec {				## draft-levine-dnsextlang
 		return unless defined wantarray;
 		require 5.008009;				# support for reference in @INC
 		my @arg = map { s/\s.*$//; qq("$_") } @stanza;	# strip descriptive text
-		return new FileHandle("RRTYPEgen @arg |");
+		return new IO::File("RRTYPEgen @arg |");
 	}
 	return undef;
 END
