@@ -1,10 +1,9 @@
 package Net::DNS::RR;
 
 #
-# $Id: RR.pm 1519 2016-12-07 11:29:53Z willem $
+# $Id: RR.pm 1552 2017-03-13 09:44:07Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1519 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1552 $)[1];
 
 
 =head1 NAME
@@ -33,6 +32,7 @@ See also the manual pages for each specific RR type.
 
 
 use strict;
+use warnings;
 use integer;
 use Carp;
 
@@ -110,7 +110,7 @@ sub _new_string {
 	my $t2 = uc $token[1] if $#token;
 
 	my ( $ttl, $class );
-	unless ( defined $t2 ) {				# <owner> <type>
+	if ( not defined $t2 ) {				# <owner> <type>
 		@token = ('ANY') if $classbyname{$t1};		# <owner> <class>
 	} elsif ( $classbyname{$t1} || $t1 =~ /^CLASS\d/ ) {
 		$class = shift @token;				# <owner> <class> [<ttl>] <type>
@@ -339,15 +339,12 @@ sub string {
 	my $tab = length($name) < 72 ? "\t" : ' ';
 	return join $tab, @core, '; no data' unless scalar @rdata;
 
-	my @note = map "; $_", $self->_annotation;
 	my @line = _wrap( join( $tab, @core, '(' ), @rdata, ')' );
-	return join "\n\t", @line, @note if scalar(@line) > 1;	# multi-line RR
 
-	for (@line) {						# single line RR
-		s/\s+[(]\s*/\t/;				# strip redundant ( )
-		s/\s+[)]$//;
-		return join "\n\t", $_, @note;
-	}
+	my $last = pop(@line);					# last or only line
+	$last = join $tab, @core, "@rdata" unless scalar(@line);
+
+	return join "\n\t", @line, _wrap( $last, map "; $_", $self->_annotation );
 }
 
 
@@ -408,8 +405,10 @@ sub generic {
 	my @class = map "CLASS$_", grep defined, $self->{class};
 	my @core = ( $self->{owner}->string, @ttl, @class, "TYPE$self->{type}" );
 	my $data = $self->rdata;
-	my $size = length($data);
-	join ' ', @core, '\\#', $size, unpack 'H*', $data;
+	my @data = ( '\\#', length($data), split /(\S{32})/, unpack 'H*', $data );
+	my @line = _wrap( "@core (", @data, ')' );
+	return join "\n\t", @line if scalar(@line) > 1;
+	join ' ', @core, @data;
 }
 
 
@@ -510,9 +509,9 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 
 sub _format_rdata {			## format rdata portion of RR string
 	my $self = shift;
-	my $data = $self->_encode_rdata;
-	my $size = length($data) || return '';
-	join ' ', '\\#', $size, unpack 'H*', $data;		# RFC3597 unknown RR format
+	my $data = $self->rdata;
+	my $size = length($data) || return '';			# RFC3597 unknown RR format
+	my @data = ( '\\#', $size, split /(\S{32})/, unpack 'H*', $data );
 }
 
 
@@ -624,7 +623,7 @@ The above example is the sorting function implemented in MX.
 
 =cut
 
-use vars qw(%rrsortfunct);
+our %rrsortfunct;
 
 sub set_rrsort_func {
 	my $class     = shift;
@@ -670,10 +669,8 @@ sub get_rrsort_func {
 # The optional second argument indicates that default values are
 # to be copied into the newly created object.
 
-use vars qw(%_LOADED %_MINIMAL);
-
-$_MINIMAL{ANY} = bless ['type' => 255], __PACKAGE__;
-%_LOADED = %_MINIMAL;
+our %_MINIMAL = ( 'ANY' => bless ['type' => 255], __PACKAGE__ );
+our %_LOADED = %_MINIMAL;
 
 sub _subclass {
 	my $class   = shift;
@@ -748,7 +745,7 @@ sub _wrap {
 
 ################################################################################
 
-use vars qw($AUTOLOAD);
+our $AUTOLOAD;
 
 sub DESTROY { }				## Avoid tickling AUTOLOAD (in cleanup)
 
