@@ -1,9 +1,9 @@
 package Net::DNS::RR::CERT;
 
 #
-# $Id: CERT.pm 1528 2017-01-18 21:44:58Z willem $
+# $Id: CERT.pm 1552 2017-03-13 09:44:07Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1528 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1552 $)[1];
 
 
 use strict;
@@ -41,7 +41,8 @@ my %certtype = (
 # source: http://www.iana.org/assignments/dns-sec-alg-numbers
 #
 {
-	my @algbyname = (		## Reserved	=> 0,	# [RFC4034][RFC4398]
+	my @algbyname = (
+		'DELETE'	     => 0,			# [RFC4034][RFC4398][RFC8087]
 		'RSAMD5'	     => 1,			# [RFC3110][RFC4034]
 		'DH'		     => 2,			# [RFC2539]
 		'DSA'		     => 3,			# [RFC3755][RFC2536]
@@ -56,8 +57,8 @@ my %certtype = (
 		'ECC-GOST'	     => 12,			# [RFC5933]
 		'ECDSAP256SHA256'    => 13,			# [RFC6605]
 		'ECDSAP384SHA384'    => 14,			# [RFC6605]
-		'Ed25519'	     => 15,			# []
-		'Ed448'		     => 16,			# []
+		'Ed25519'	     => 15,			# [RFC8080]
+		'Ed448'		     => 16,			# [RFC8080]
 
 		'INDIRECT'   => 252,				# [RFC4034]
 		'PRIVATEDNS' => 253,				# [RFC4034]
