@@ -1,13 +1,13 @@
 package Net::DNS::RR::MINFO;
 
 #
-# $Id: MINFO.pm 1390 2015-09-11 11:42:11Z willem $
+# $Id: MINFO.pm 1528 2017-01-18 21:44:58Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1390 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1528 $)[1];
 
 
 use strict;
+use warnings;
 use base qw(Net::DNS::RR);
 
 =head1 NAME
@@ -61,7 +61,7 @@ sub rmailbx {
 	my $self = shift;
 
 	$self->{rmailbx} = new Net::DNS::Mailbox1035(shift) if scalar @_;
-	$self->{rmailbx}->address if defined wantarray && $self->{rmailbx};
+	$self->{rmailbx}->address if $self->{rmailbx};
 }
 
 
@@ -69,7 +69,7 @@ sub emailbx {
 	my $self = shift;
 
 	$self->{emailbx} = new Net::DNS::Mailbox1035(shift) if scalar @_;
-	$self->{emailbx}->address if defined wantarray && $self->{emailbx};
+	$self->{emailbx}->address if $self->{emailbx};
 }
 
 
