@@ -1,10 +1,9 @@
 package Net::DNS::Update;
 
 #
-# $Id: Update.pm 1367 2015-06-29 08:53:56Z willem $
+# $Id: Update.pm 1527 2017-01-18 21:42:48Z willem $
 #
-use vars qw($VERSION @ISA);
-$VERSION = (qw$LastChangedRevision: 1367 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1527 $)[1];
 
 
 =head1 NAME
@@ -31,6 +30,7 @@ Programmers should refer to RFC2136 for dynamic update semantics.
 
 
 use strict;
+use warnings;
 use base 'Net::DNS::Packet';
 
 use Carp;
@@ -52,9 +52,9 @@ Section 2.3).
 Programs must use the push() method to add RRs to the prerequisite,
 update, and additional sections before performing the update.
 
-Arguments are the zone name and the class.  If the zone is omitted,
-the default domain will be taken from the resolver configuration.
-If the class is omitted, it defaults to IN.
+Arguments are the zone name and the class.  The zone and class may
+be undefined or omitted and default to the default domain from the
+resolver configuration and IN respectively.
 
 =cut
 
@@ -62,14 +62,14 @@ sub new {
 	shift;
 	my ( $zone, @class ) = @_;
 
-	unless ( scalar @_ ) {
+	unless ( defined $zone ) {
 		require Net::DNS::Resolver;
-		my $resolver = new Net::DNS::Resolver();
-
-		($zone) = $resolver->searchlist;		# default from resolver config
+		($zone) = new Net::DNS::Resolver()->domain;	# default from resolver config
 	}
 
 	eval {
+		local $SIG{__DIE__};
+
 		my $self = __PACKAGE__->SUPER::new( $zone, 'SOA', @class );
 
 		my $header = $self->header;
@@ -155,6 +155,9 @@ __END__
 The first example below shows a complete program.
 Subsequent examples show only the creation of the update packet.
 
+Although the examples are presented using the string form of RRs,
+the corresponding ( name => value ) form may also be used.
+
 =head2 Add a new host
 
     #!/usr/bin/perl
@@ -195,7 +198,7 @@ Subsequent examples show only the creation of the update packet.
     $update->push( prereq => yxdomain('example.com') );
     $update->push( update => rr_add('example.com MX 10 mailhost.example.com') );
 
-=head2 Add a TXT record for a name that doesn't exist
+=head2 Add a TXT record for a name that does not exist
 
     my $update = new Net::DNS::Update('example.com');
     $update->push( prereq => nxdomain('info.example.com') );
